@@ -54,8 +54,7 @@ struct {
   const char *code;
   EphyLanguageGroup groups;
 }
-encoding_entries [] =
-{
+encoding_entries [] = {
   { N_("Arabic (_IBM-864)"), "IBM864", LG_ARABIC },
   { N_("Arabic (ISO-_8859-6)"), "ISO-8859-6", LG_ARABIC },
   { N_("Arabic (_MacArabic)"), "x-mac-arabic", LG_ARABIC },
@@ -182,10 +181,10 @@ ephy_encodings_class_init (EphyEncodingsClass *klass)
 }
 
 static EphyEncoding *
-add_encoding (EphyEncodings    *encodings,
-              const char       *title,
-              const char       *code,
-              EphyLanguageGroup groups)
+add_encoding (EphyEncodings     *encodings,
+              const char        *title,
+              const char        *code,
+              EphyLanguageGroup  groups)
 {
   EphyEncoding *encoding;
 
@@ -206,7 +205,7 @@ ephy_encodings_get_encoding (EphyEncodings *encodings,
 {
   EphyEncoding *encoding;
 
-  g_return_val_if_fail (EPHY_IS_ENCODINGS (encodings), NULL);
+  g_assert (EPHY_IS_ENCODINGS (encodings));
 
   encoding = g_hash_table_lookup (encodings->hash, code);
 
@@ -244,8 +243,8 @@ get_encodings_foreach (gpointer key,
 }
 
 GList *
-ephy_encodings_get_encodings (EphyEncodings    *encodings,
-                              EphyLanguageGroup group_mask)
+ephy_encodings_get_encodings (EphyEncodings     *encodings,
+                              EphyLanguageGroup  group_mask)
 {
   GList *list = NULL;
   GetEncodingsData data;
@@ -273,7 +272,7 @@ ephy_encodings_get_all (EphyEncodings *encodings)
 {
   GList *l = NULL;
 
-  g_return_val_if_fail (EPHY_IS_ENCODINGS (encodings), NULL);
+  g_assert (EPHY_IS_ENCODINGS (encodings));
 
   g_hash_table_foreach (encodings->hash, (GHFunc)get_all_encodings, &l);
 
@@ -287,8 +286,8 @@ ephy_encodings_add_recent (EphyEncodings *encodings,
   GSList *element, *l;
   GVariantBuilder builder;
 
-  g_return_if_fail (EPHY_IS_ENCODINGS (encodings));
-  g_return_if_fail (code != NULL);
+  g_assert (EPHY_IS_ENCODINGS (encodings));
+  g_assert (code != NULL);
 
   if (ephy_encodings_get_encoding (encodings, code, FALSE) == NULL)
     return;
@@ -331,13 +330,13 @@ ephy_encodings_get_recent (EphyEncodings *encodings)
   GSList *l;
   GList *list = NULL;
 
-  g_return_val_if_fail (EPHY_IS_ENCODINGS (encodings), NULL);
+  g_assert (EPHY_IS_ENCODINGS (encodings));
 
   for (l = encodings->recent; l != NULL; l = l->next) {
     EphyEncoding *encoding;
 
     encoding = ephy_encodings_get_encoding (encodings, (char *)l->data, FALSE);
-    g_return_val_if_fail (EPHY_IS_ENCODING (encoding), NULL);
+    g_assert (EPHY_IS_ENCODING (encoding));
 
     list = g_list_prepend (list, encoding);
   }
