@@ -38,10 +38,10 @@ webkit_web_extension_initialize_with_user_data (WebKitWebExtension *webkit_exten
   const char *server_address;
   const char *profile_dir;
   gboolean private_profile;
-  gboolean should_remember_passwords;
+  gboolean browser_mode;
   g_autoptr (GError) error = NULL;
 
-  g_variant_get (user_data, "(&sm&sm&sbb)", &guid, &server_address, &profile_dir, &should_remember_passwords, &private_profile);
+  g_variant_get (user_data, "(&sm&sm&sbb)", &guid, &server_address, &profile_dir, &private_profile, &browser_mode);
 
   if (!server_address) {
     g_warning ("UI process did not start D-Bus server, giving up.");
@@ -53,16 +53,14 @@ webkit_web_extension_initialize_with_user_data (WebKitWebExtension *webkit_exten
 
   ephy_debug_init ();
 
-  ephy_settings_set_is_web_process_extension ();
-
   extension = ephy_web_process_extension_get ();
 
   ephy_web_process_extension_initialize (extension,
                                          webkit_extension,
                                          guid,
                                          server_address,
-                                         should_remember_passwords,
-                                         private_profile);
+                                         private_profile,
+                                         browser_mode);
 }
 
 static void __attribute__((destructor))
