@@ -61,6 +61,7 @@ struct _EphyHeaderBar {
   GtkWidget *bookmarks_button;
   GtkWidget *page_menu_button;
   GtkWidget *zoom_level_button;
+  GtkWidget *restore_button;
 };
 
 G_DEFINE_TYPE (EphyHeaderBar, ephy_header_bar, GTK_TYPE_HEADER_BAR)
@@ -114,6 +115,18 @@ sync_chromes_visibility (EphyHeaderBar *header_bar)
   gtk_widget_set_visible (header_bar->page_menu_button, chrome & EPHY_WINDOW_CHROME_MENU);
 }
 
+void
+fullscreen_changed_cb (EphyHeaderBar *header_bar)
+{
+  gboolean fullscreen;
+
+  g_object_get (header_bar->window, "fullscreen", &fullscreen, NULL);
+
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar), !fullscreen);
+  gtk_widget_set_visible (header_bar->restore_button, fullscreen);
+  ephy_action_bar_set_is_fullscreen (header_bar->action_bar_start, fullscreen);
+}
+
 static void
 add_bookmark_button_clicked_cb (EphyLocationEntry *entry,
                                 gpointer          *user_data)
@@ -128,6 +141,19 @@ add_bookmark_button_clicked_cb (EphyLocationEntry *entry,
   g_action_activate (action, NULL);
 }
 
+static void
+restore_button_clicked_cb (GtkButton     *button,
+                           EphyHeaderBar *header_bar)
+{
+  GActionGroup *action_group;
+  GAction *action;
+
+  action_group = gtk_widget_get_action_group (GTK_WIDGET (header_bar->window), "win");
+  action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "fullscreen");
+
+  g_action_activate (action, NULL);
+}
+
 static void
 update_revealer_visibility (GtkRevealer *revealer)
 {
@@ -144,13 +170,16 @@ ephy_header_bar_constructed (GObject *object)
   GtkWidget *page_menu_popover;
   GtkBuilder *builder;
   EphyEmbedShell *embed_shell;
-  HdyColumn *column;
+  GtkSizeGroup *downloads_size_group;
 
   G_OBJECT_CLASS (ephy_header_bar_parent_class)->constructed (object);
 
   g_signal_connect_object (header_bar->window, "notify::chrome",
                            G_CALLBACK (sync_chromes_visibility), header_bar,
                            G_CONNECT_SWAPPED);
+  g_signal_connect_object (header_bar->window, "notify::fullscreen",
+                           G_CALLBACK (fullscreen_changed_cb), header_bar,
+                           G_CONNECT_SWAPPED);
 
   /* Start action elements */
   header_bar->action_bar_start = ephy_action_bar_start_new ();
@@ -173,13 +202,27 @@ ephy_header_bar_constructed (GObject *object)
     header_bar->title_widget = EPHY_TITLE_WIDGET (ephy_title_box_new ());
   else
     header_bar->title_widget = EPHY_TITLE_WIDGET (ephy_location_entry_new ());
-  column = hdy_column_new ();
-  gtk_widget_set_hexpand (GTK_WIDGET (column), TRUE);
-  gtk_widget_show (GTK_WIDGET (column));
-  hdy_column_set_maximum_width (column, 860);
-  hdy_column_set_linear_growth_width (column, 560);
-  gtk_container_add (GTK_CONTAINER (column), GTK_WIDGET (header_bar->title_widget));
-  gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar), GTK_WIDGET (column));
+
+  if (is_desktop_pantheon ()) {
+    /* Use a full-width entry on Pantheon */
+    gtk_widget_set_hexpand (GTK_WIDGET (header_bar->title_widget), TRUE);
+    gtk_widget_set_margin_start (GTK_WIDGET (header_bar->title_widget), 6);
+    gtk_widget_set_margin_end (GTK_WIDGET (header_bar->title_widget), 6);
+
+    gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar), GTK_WIDGET (header_bar->title_widget));
+  } else {
+    HdyColumn *column;
+
+    column = hdy_column_new ();
+    gtk_widget_set_hexpand (GTK_WIDGET (column), TRUE);
+    gtk_widget_show (GTK_WIDGET (column));
+    hdy_column_set_maximum_width (column, 860);
+    hdy_column_set_linear_growth_width (column, 560);
+    gtk_container_add (GTK_CONTAINER (column), GTK_WIDGET (header_bar->title_widget));
+
+    gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar), GTK_WIDGET (column));
+  }
+
   gtk_widget_show (GTK_WIDGET (header_bar->title_widget));
 
   if (EPHY_IS_LOCATION_ENTRY (header_bar->title_widget)) {
@@ -193,6 +236,16 @@ ephy_header_bar_constructed (GObject *object)
                              0);
   }
 
+  /* Fullscreen restore button */
+  header_bar->restore_button = gtk_button_new_from_icon_name ("view-restore-symbolic",
+                                                              GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_valign (header_bar->restore_button, GTK_ALIGN_CENTER);
+  g_signal_connect_object (header_bar->restore_button, "clicked",
+                           G_CALLBACK (restore_button_clicked_cb),
+                           header_bar, 0);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar),
+                           GTK_WIDGET (header_bar->restore_button));
+
   /* Page Menu */
   button = gtk_menu_button_new ();
   header_bar->page_menu_button = button;
@@ -253,6 +306,14 @@ ephy_header_bar_constructed (GObject *object)
 
   gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar),
                            GTK_WIDGET (header_bar->end_revealer));
+
+  /* Sync the size of placeholder in EphyActionBarStart with downloads button */
+  downloads_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+  gtk_size_group_add_widget (downloads_size_group,
+                             ephy_action_bar_start_get_placeholder (header_bar->action_bar_start));
+  gtk_size_group_add_widget (downloads_size_group,
+                             ephy_action_bar_end_get_downloads_revealer (header_bar->action_bar_end));
+  g_object_unref (downloads_size_group);
 }
 
 static void
