@@ -24,6 +24,7 @@
 #include "ephy-notebook.h"
 
 #include "ephy-debug.h"
+#include "ephy-desktop-utils.h"
 #include "ephy-dnd.h"
 #include "ephy-embed-utils.h"
 #include "ephy-embed.h"
@@ -370,8 +371,11 @@ update_tabs_visibility (EphyNotebook *nb,
   if (before_inserting)
     num++;
 
-  policy = g_settings_get_enum (EPHY_SETTINGS_UI,
-                                EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY);
+  if (is_desktop_pantheon ())
+    policy = EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_ALWAYS;
+  else
+    policy = g_settings_get_enum (EPHY_SETTINGS_UI,
+                                  EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY);
 
   if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION &&
       nb->adaptive_mode != EPHY_ADAPTIVE_MODE_NARROW &&
@@ -383,6 +387,15 @@ update_tabs_visibility (EphyNotebook *nb,
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), nb->tabs_allowed && show_tabs);
 }
 
+static gboolean
+expand_tabs_bar (void)
+{
+  if (is_desktop_pantheon ())
+    return FALSE;
+  return g_settings_get_boolean (EPHY_SETTINGS_UI,
+                                 EPHY_PREFS_UI_EXPAND_TABS_BAR);
+}
+
 static void
 expand_tabs_changed_cb (GSettings    *settings,
                         char         *key,
@@ -392,8 +405,7 @@ expand_tabs_changed_cb (GSettings    *settings,
   GList *l;
   gboolean expand;
 
-  expand = g_settings_get_boolean (EPHY_SETTINGS_UI,
-                                   EPHY_PREFS_UI_EXPAND_TABS_BAR),
+  expand = expand_tabs_bar ();
 
   tabs = gtk_container_get_children (GTK_CONTAINER (nb));
 
@@ -493,9 +505,10 @@ get_last_pinned_tab_pos (EphyNotebook *notebook)
 }
 
 static void
-ephy_notebook_ensure_pinned_tab_position (GtkNotebook *notebook,
-                                          GtkWidget   *child,
-                                          guint        page_num)
+page_reordered_cb (GtkNotebook *notebook,
+                   GtkWidget   *child,
+                   guint        page_num,
+                   gpointer     user_data)
 {
   int last_pinned_tab_pos = get_last_pinned_tab_pos (EPHY_NOTEBOOK (notebook));
   gboolean is_current_tab_pinned = ephy_notebook_tab_is_pinned (EPHY_NOTEBOOK (notebook), EPHY_EMBED (child));
@@ -508,15 +521,6 @@ ephy_notebook_ensure_pinned_tab_position (GtkNotebook *notebook,
   }
 }
 
-static void
-page_reordered_cb (GtkNotebook *notebook,
-                   GtkWidget   *child,
-                   guint        page_num,
-                   gpointer     user_data)
-{
-  ephy_notebook_ensure_pinned_tab_position (notebook, child, page_num);
-}
-
 static void
 ephy_notebook_init (EphyNotebook *notebook)
 {
@@ -565,21 +569,26 @@ static void
 ephy_notebook_constructed (GObject *object)
 {
   EphyNotebook *notebook = EPHY_NOTEBOOK (object);
-  GtkWidget *hbox;
   GtkWidget *button;
   EphyPagesPopover *popover;
 
   G_OBJECT_CLASS (ephy_notebook_parent_class)->constructed (object);
 
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_notebook_set_action_widget (GTK_NOTEBOOK (notebook), hbox, GTK_PACK_END);
-  gtk_widget_show (hbox);
+  if (is_desktop_pantheon ()) {
+    button = gtk_button_new_from_icon_name ("tab-new-symbolic", GTK_ICON_SIZE_MENU);
+    /* Translators: tooltip for the new tab button */
+    gtk_widget_set_tooltip_text (button, _("Open a new tab"));
+    gtk_actionable_set_action_name (GTK_ACTIONABLE (button), "win.new-tab");
+    gtk_style_context_add_class (gtk_widget_get_style_context (button), "flat");
+    gtk_notebook_set_action_widget (GTK_NOTEBOOK (notebook), button, GTK_PACK_START);
+    gtk_widget_show (button);
+  }
 
   button = gtk_menu_button_new ();
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   /* Translators: tooltip for the tab switcher menu button */
   gtk_widget_set_tooltip_text (button, _("View open tabs"));
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+  gtk_notebook_set_action_widget (GTK_NOTEBOOK (notebook), button, GTK_PACK_END);
   gtk_widget_show (button);
 
   notebook->tab_menu = g_menu_new ();
@@ -796,8 +805,7 @@ ephy_notebook_insert_page (GtkNotebook *gnotebook,
   gtk_notebook_set_tab_detachable (gnotebook, tab_widget, TRUE);
   gtk_container_child_set (GTK_CONTAINER (gnotebook),
                            GTK_WIDGET (tab_widget),
-                           "tab-expand", g_settings_get_boolean (EPHY_SETTINGS_UI,
-                                                                 EPHY_PREFS_UI_EXPAND_TABS_BAR),
+                           "tab-expand", expand_tabs_bar (),
                            NULL);
 
   return position;
@@ -820,8 +828,7 @@ ephy_notebook_add_tab (EphyNotebook *notebook,
 
   gtk_container_child_set (GTK_CONTAINER (notebook),
                            GTK_WIDGET (embed),
-                           "tab-expand", g_settings_get_boolean (EPHY_SETTINGS_UI,
-                                                                 EPHY_PREFS_UI_EXPAND_TABS_BAR),
+                           "tab-expand", expand_tabs_bar (),
                            NULL);
 
   if (jump_to) {
@@ -894,8 +901,6 @@ ephy_notebook_page_added (GtkNotebook *notebook,
   if (GTK_NOTEBOOK_CLASS (ephy_notebook_parent_class)->page_added != NULL)
     GTK_NOTEBOOK_CLASS (ephy_notebook_parent_class)->page_added (notebook, child, page_num);
 
-  ephy_notebook_ensure_pinned_tab_position (notebook, child, page_num);
-
   ephy_notebook_rebuild_tab_menu (EPHY_NOTEBOOK (notebook));
 }
 
@@ -1010,7 +1015,6 @@ ephy_notebook_tab_set_pinned (EphyNotebook *notebook,
   gboolean expanded;
 
   gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (notebook), embed, !is_pinned);
-  gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (notebook), embed, !is_pinned);
   tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (notebook), embed);
   ephy_tab_label_set_pinned (tab_label, is_pinned);
 
@@ -1018,7 +1022,7 @@ ephy_notebook_tab_set_pinned (EphyNotebook *notebook,
     gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), embed, 0);
     expanded = FALSE;
   } else {
-    expanded = g_settings_get_boolean (EPHY_SETTINGS_UI, EPHY_PREFS_UI_EXPAND_TABS_BAR);
+    expanded = expand_tabs_bar ();
     gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), embed, -1);
   }
 
